@@ -9,17 +9,31 @@
 #'                    does not do it on its own.
 #' @param ssl_verifypeer analog to CURL option
 #'   \url{https://curl.haxx.se/libcurl/c/CURLOPT_SSL_VERIFYPEER.html}
-#'   -- and might help with robots.txt file retrieval in some cases              #'
+#'   -- and might help with robots.txt file retrieval in some cases
+#'
+#' @param rt_request_handler handler function that handles request according to
+#'     the event handlers specified
+#'
 #' @export
 #'
 get_robotstxts <-
   function(
     domain,
-    warn           = TRUE,
-    force          = FALSE,
-    user_agent     = utils::sessionInfo()$R.version$version.string,
-    ssl_verifypeer = c(1,0),
-    use_futures    = FALSE
+    warn                      = TRUE,
+    force                     = FALSE,
+    user_agent                = utils::sessionInfo()$R.version$version.string,
+    ssl_verifypeer            = c(1,0),
+    use_futures               = FALSE,
+    verbose                   = FALSE,
+    rt_request_handler        = robotstxt::rt_request_handler,
+    rt_robotstxt_http_getter  = robotstxt::get_robotstxt_http_get,
+    on_server_error       = on_server_error_default,
+    on_client_error       = on_client_error_default,
+    on_not_found          = on_not_found_default,
+    on_redirect           = on_redirect_default,
+    on_domain_change      = on_domain_change_default,
+    on_file_type_mismatch = on_file_type_mismatch_default,
+    on_suspect_content    = on_suspect_content_default
   ){
 
 
@@ -32,6 +46,7 @@ get_robotstxts <-
           warn             = warn[1],
           force            = force[1],
           ssl_verifypeer   = ssl_verifypeer[1],
+          verbose          = verbose,
           stringsAsFactors = FALSE
         )
 
@@ -44,6 +59,7 @@ get_robotstxts <-
           warn             = warn[1],
           force            = force[1],
           ssl_verifypeer   = ssl_verifypeer[1],
+          verbose          = verbose,
           stringsAsFactors = FALSE
         )
     }
@@ -72,11 +88,21 @@ get_robotstxts <-
         )
 
         get_robotstxt(
-          domain         = x$domain,
-          warn           = x$warn,
-          force          = x$force,
-          user_agent     = x$user_agent,
-          ssl_verifypeer = x$ssl_verifypeer
+          domain                    = x$domain,
+          warn                      = x$warn,
+          force                     = x$force,
+          user_agent                = x$user_agent,
+          ssl_verifypeer            = x$ssl_verifypeer,
+          verbose                   = x$verbose,
+          rt_request_handler        = rt_request_handler,
+          rt_robotstxt_http_getter  = rt_robotstxt_http_getter,
+          on_server_error           = on_server_error,
+          on_client_error           = on_client_error,
+          on_not_found              = on_not_found,
+          on_redirect               = on_redirect,
+          on_domain_change          = on_domain_change,
+          on_file_type_mismatch     = on_file_type_mismatch,
+          on_suspect_content        = on_suspect_content
         )
 
       }
